@@ -9,7 +9,7 @@ use Wx qw[:everything];
 use Wx::XRC;
 
 # use Wx::Perl::PubSub qw(:global);
-use Gtk2::Ex::DbLinker::DbiDataManager;
+#se Gtk2::Ex::DbLinker::DbiDataManager;
 use Data::Dumper;
 use Wx::Perl::DbLinker::Wxdatasheet;
 
@@ -66,11 +66,11 @@ sub new {
 	     $self->{frame} = $self->{xrc}->LoadFrame(undef, $href->{main_name});
 	     $self->{frame}->SetSize($self->{size});
 	     #die unless (defined $href->{dbh});
-	     if (defined $href->{dbh}){
+	     if (defined $href->{schema}){
 		     #my ($name ) = ($href->{dbh}->{Name}=~/database=(.*);/);
 	    	$self->show_tables(
 		    "SELECT name FROM sqlite_master WHERE type = 'table' AND name NOT LIKE 'sqlite_%'",
-		    $href->{dbh}
+		    $href->{schema}
 	    	);
 		#$self->show_querries($href->{dbh});
            	}
@@ -83,6 +83,9 @@ sub new {
      # my $f = $self->{xrc}->LoadFrame(undef, 'mainwindow');
      # $self->signal_connect();    
     
+     $self->{w2disable} = [];
+     $self->{w2enable} =  [];
+
 
    return $self;
 }
@@ -182,7 +185,8 @@ sub load_grid {
  	my $href = $argref->{datasheet_param};
 	my $where = Wx::Window::FindWindowById( Wx::XmlResource::GetXRCID($where_name), $top_panel );
 	confess("Can't find any object named ", $where_name, " to place the grid into") unless ($where);
-	$where->SetBackgroundColour(wxBLACK);
+	
+	$where->SetBackgroundColour($$argref{bg})if ($$argref{bg});
 	
 	my $s = $where->GetSizer();
 	$s = ( defined $s ? $s :  Wx::BoxSizer->new(wxVERTICAL));
@@ -218,19 +222,6 @@ sub connect_signal_for {
 	my ($self, $wname, $sub_ref, $data) = @_;
 	my $w = $self->get_object($wname);
 	croak ("Dnav connect_signal_for failed since no widget instance exists for $wname") unless($w);
-	#$signal = ($signal?$signal:"clicked");
-=for comment
-	if ($signal eq "clicked") {
-		EVT_BUTTON($self->{frame}, $b,  sub { &$sub_ref($b, $data) });
-
-		#$b->subscribe('Clicked', sub { \&$sub_ref($data) });
-       } elsif ($signal eq "changed") {
-	       #$self->list_children;
-	       $self->{log}->debug("connect_signal_evt_text for " . $btn);
-	       EVT_TEXT($self->{frame}, $b,  sub { &$sub_ref($b, $data) }); #yes but setter in displaydata are done using ChangeValue and this does not generate event
-		
-       }
-=cut
 	my $name = ref $w;
 	my $signal = $signals{$name};
 	print Dumper($name);
@@ -292,8 +283,9 @@ sub on_apply_clicked 	{ my ($b, $self) = @_; $self->{log}->debug("in Wx_dnav...\
 
 
 sub show_tables {
-	my ($self, $sql, $dbh) = @_;
+	my ($self, $sql, $schema) = @_;
 	#my $dbh = $self->{globals}->{connections}->{dbh};
+	my $dbh = $schema->storage->dbh;
 	my  $sth = $dbh->prepare($sql);	
 	$sth->execute;
 	#my $menu = Wx::Window::FindWindowById( Wx::XmlResource::GetXRCID('m_menubar1'), $self->{frame});
@@ -306,7 +298,7 @@ sub show_tables {
 		$self->{log}->debug(" menu table: ".  $row[0]);
 		#my $t = Gtk2::MenuItem->new($row[0]);
 		my $t = $menu->Append($id, $row[0]); 
-		EVT_MENU( $self->{frame}, $id,  sub {display_tbl($self, {name => $row[0], dbh => $dbh} );});
+		EVT_MENU( $self->{frame}, $id,  sub {display_tbl($self, {name => $row[0], schema => $schema} );});
 		# push @tbl, $t
 		$id++;
 		#$t->show;
@@ -318,18 +310,23 @@ sub show_tables {
 sub display_tbl {
 my ($self, $href) = @_;
 
-	#my $treeview = Gtk2::TreeView->new();
-	# my $rs_def;
+	my %class = (speaks => 'Speak', langues => 'Langue', countries =>'Country');
+
 	my $data;
 	if ($href->{name}){
+		my $name = $class{ $href->{name} };
+		my $rs = $href->{schema}->resultset($name)->search_rs();
 		#$rs_def = {dbh =>$dbh,sql=> {	select => "*", from => $href->{name}},	treeview =>  $treeview	}
-		$data =  Gtk2::Ex::DbLinker::DbiDataManager->new({ sql=>{select => "*", from=> $href->{name}}, dbh=>$href->{dbh}});
-	} elsif ($href->{sql}){
+		$data =  Gtk2::Ex::DbLinker::DbcDataManager->new({rs => $rs });
+	} 
+=for comment
+	elsif ($href->{sql}){
 		#$rs_def = { dbh => $dbh,sql=> {	pass_through => $href->{sql}},	treeview => $treeview}
 		$data = Gtk2::Ex::DbLinker::DbiDataManager->new( $href);
 		
 	}
-	my $f = Wx_dnav->new({ismain=>1, size=> $self->{size},  main_name=>'mainwindow', main_file=>'main.xrc'});
+=cut
+	my $f = Wx_dnav->new({ismain=>1, size=> $self->{size},  main_name=>'mainwindow', main_file=>'../xrc/main.xrc'});
 	$f->load_panel('mainwindow', 'xrc/nav.xrc', 'm_dnav_panel' );
 	#my $scroll = Gtk2::ScrolledWindow->new;
 =for comment
@@ -418,44 +415,78 @@ sub show_all_except {
 
 sub widgets_set_sensitivity {
 
- 	my ($self, $lst_ref, $val) = @_;
+ 	my ($self, $val) = @_;
 
-	# print "set_sensitivity $val size: ", scalar @$lst_ref , "\n";
-	for my $w (@$lst_ref){
+	$self->{log}->debug("set_sensitivity " . ( defined $val ? $val : " undef"));
+	for my $w (@{$self->{w2disable}}){
 		# print $w->get_name,"\n"
 			#$w->set_sensitive($val);
 			$w->Enable($val);
+			$self->{log}->debug(($val ? " en" : " dis") . "abling " . $w->GetName);
 	
 	}
+	return if ($val == 1);
+	for my $w (@{$self->{w2enable}}){
+		my $p;
+		#if (ref $w eq "Wx::Panel") {
+		#	$p = $w;
+		#	for my $c ($p->GetChildren){
+		#		$c->Enable(1);
+		#	}
+		#} else {
+		#	$p = $w->GetParent;
+		# }
+		#$self->{log}->debug("enabling " . $p->GetName . " wich is " . ($p->IsEnabled ? " enabled" : " disabled"));
+		#$self->{log}->debug("enabling parent " . ( $p->Enable(1)  ? " with" : " without") . " success" );
+		$self->{log}->debug("enabling widget " . $w->GetName  . ( $w->Enable(1)  ? " with" : " without") . " success" );
+		
+		#$done = $w->Enable(1);
+		#$self->{log}->debug(($done ? " with" : " without") . " success");
+	}
 }
 
-sub populate_widgets {
- my ($self, $w, $lst_ref, $keepit, $no_warn) = @_;
-# print "populate widgtets ", $w->get_name, " " , ref $w, " ", ( $w->isa('Gtk2::Container') ? " is a container" : " is not a container"), "\n";
-croak("widget undefined") unless $w;
+#the array ref of control to disable is stored here and not in the calling module
+#$keepit is a array ref of widgets name not to disable
+#
+#
 
-#my $class = Wx::ClassInfo::FindClass('Wx::Control');
-# return unless  $w->IsKindOf($class);
- return unless (UNIVERSAL::isa($w, 'Wx::Control'));
- my @c = $w->GetChildren;
-if( !defined $no_warn && scalar @c == 0) {
- 	carp "populate_widgets received a container widget without any children" ;
- }
- for my $c ($w->GetChildren){
+sub populate_widgets {
+	my ($self, $w, $keepit, $no_warn) = @_;
+  	$self->{log}->debug("populate widgtets " . $w->GetName. " ref: " . (ref $w) . " isa control " . (UNIVERSAL::isa($w, 'Wx::Window')? " true" : " false")) ; #, " ", ( $w->isa('Gtk2::Container') ? " is a container" : " is not a container"), "\n";
+	croak("widget undefined") unless $w;
+# do this only once
+	if (! defined $self->{hw2e}){
+		#$self->{log}->debug("building hw2e");
+		foreach my $name (@$keepit){
+			$self->{hw2e}->{$name} =1;
+		}
+
+	}
+	my %class =  map { $_, 1} qw(Wx::TextCrl Wx::ComboBox Wx::ListBox Wx::Button Wx::SpinCtrl Wx::Static::Text Wx::CheckBox Wx::SpinButton);
+
+ 	return unless (UNIVERSAL::isa($w, 'Wx::Window'));
+	 my @c = $w->GetChildren;
+	if( ! defined $no_warn && scalar @c == 0) {
+ 		carp "populate_widgets received a container widget without any children" ;
+ 	}
+	 for my $c ($w->GetChildren){
 	 	my $id = $c->GetName;
 		my $name = ref $c;
-		# print "populate widgets 1: $name\n";
+		#$self->{log}->debug( "populate widgets 1: " . $name);
 		# my $id =getID($c);
 		#if ($c->get_sensitive && $c->isa('Gtk2::Buildable') && $name ne "GtkVBox" && $name ne "GtkHBox" && $id ne ""){
 		if ($c->IsEnabled() && $name ne "Wx::BoxSizer" && $id ne ""){
 		
 			# print "populate widgets 2: $id $name\n";	
-			if ($id ne $keepit){
+			if ($self->{hw2e}->{$id}){
 				# $c->set_sensitive(0);
-				push @$lst_ref, $c;
+				push @{$self->{w2enable}}, $c;
+			} else { 
+				
+				push @{$self->{w2disable}}, $c if($class{$name});
 			} 
 		}
-		$self->populate_widgets ($c, $lst_ref, $keepit, 1);
+		$self->populate_widgets ($c, $keepit, 1);
  	}
 }
 
