@@ -2,7 +2,8 @@
 use strict;
 use warnings;
 
-
+#See the second half of this file for the Wx::Perl::DbLinker::DBGridTable package
+#
 #>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
 #
 package Wx::Perl::DbLinker::Wxdatasheet;
@@ -60,6 +61,7 @@ sub new {
 	#$self->{null_string} = $$req{null_string} || "null";
 	$self->{on_changed} = $$req{on_changed}; # Code that runs when a record is changed ( any column )
 	$self->{on_row_select} = $$req{on_row_select};
+	$self->{after_update} = $$req{after_update};
 	$self->{borders_size} = $$req{borders_size} || [22, 20]; #array ref of row1 height and col1 width
 	#$self->{multi_select} = $$req{multi_select};
 
@@ -319,7 +321,7 @@ sub _setup_combo {
   for (my $row_pos = 0; $row_pos < $last ; $row_pos ++ ) {
         
      
-	# $self->{log}->debug("Datasheet setupcombo set row pos " . $row_pos);
+	$self->{log}->debug("Datasheet setupcombo set row pos " . $row_pos);
 	$dman->set_row_pos( $row_pos );
 
 	#push @model_row, $model->append;
@@ -360,19 +362,12 @@ sub get_column_value {
     
     my ( $self, $sql_fieldname ) = @_;
     
-    #my @selected_rows = $self->GetSelectedRows;
-    # $self->{log}->debug("get_column_value selected rows : " .  Dumper (@selected_rows)); 
-     
-    #if ( ! scalar(@selected_rows) ) {
-    #    return 0;
-    #}
     my $current_row = $self->{current_row};
  	$self->{log}->debug("get_column_value current row : " .( defined $current_row ? $current_row : " undef"));
     # my $model = $self->{treeview}->get_model;
    
   return unless (defined $current_row);
    
-    #foreach my $selected_row ( @selected_rows ) {
         my $value;
         my $column_no = $self->colnumber_from_name( $sql_fieldname );
 
@@ -386,15 +381,6 @@ sub get_column_value {
         	$value = $self->GetCellValue( $current_row, $column_no );
 	}
 
-	# push @selected_values, $value;
-        
-     #}
-
-     #if ( $self->{multi_select} ) {
-     #   return @selected_values;
-     #} else {
-     #   return $selected_values[0];
-     #}
     return $value;
 }
 
@@ -465,13 +451,9 @@ sub _changed {
 
  sub update {
 	my ($self) = @_;
+	$self->{log}->debug("update");
 		my $last = $self->{dman}->row_count;
-	#for (my $i=0 ; $i < $last; $i++){
-	# 	$self->{dman}->set_row_pos($i);
-	#	my $v =  $self->{dman}->get_field('docpath');
-	#	$self->{log}->debug("update row: ", $i , " docpath: ", (defined $v ? $v : " undef") );
-	 
-	# }	
+
 	$self->ClearGrid;
 	#$self->ForceRefresh;
 	my $table = $self->_setup_gridtable;
@@ -479,17 +461,11 @@ sub _changed {
 	#$self->{log}->debug("update : ",join(" ", @));
 	 $self->SetTable($table);
 	 $self->_setup_grid;
-=for comment
-if ($field->{renderer} eq "combo" && defined $x && $x ne "") {
-					my @renderers = $field->{ $treeview_type . "_column" }->get_cell_renderers;
-					my $combomodel = $renderers[0]->get("model");
-					# $self->{log}->debug("data-t: " . $field->{ $treeview_type . "_column" }->{renderer}->{data_type});
-					my $value = $self->_combo_value($combomodel, $x,  $field->{ $treeview_type . "_column" }->{renderer}->{comp});
-				# push @combo_values, $value;
-					push @model_row, $renderers[0]->{col_data}, $value;
+	 if (defined $self->{after_update}){
+	 
+		$self->{after_update}();
+	}
 
-				} 
-=cut
 
 }
 
@@ -590,6 +566,10 @@ sub apply {
     }
 
     # $model->signal_handler_unblock( $self->{changed_signal} );
+     if (defined $self->{after_update}){
+	 
+		$self->{after_update}();
+	}
 
 } #apply
 
@@ -872,15 +852,9 @@ sub GetValue {
 	     if (defined $$self{array}->[$row] ){ #retourner $result s'il a ete attribue par SetValue
 		      $result =  $$self{array}->[$row][$col];
 	     } else { confess("array undef");}
-	       #if ($row < $self->{dman}->row_count) 
-	       #$self->{dman}->set_row_pos($row);
-	    #die Dumper  $self->{fields}[$col];
-	    #$$self{array}->[$row][$col]->GetValue;
 	   
 	   my $fname = $self->{fields}[$col]->{name};
-	    #	$result = $self->{dman}->get_field($fname);
-	    # }
-	$self->{log}->debug("GetValue: ", (defined $result? $result: " undef"), " Field: ", $fname, " row: ", $row, " col: ", $col);
+	   #$self->{log}->debug("GetValue: ", (defined $result? $result: " undef"), " Field: ", $fname, " row: ", $row, " col: ", $col);
 	   
 	    
     } else {
@@ -901,13 +875,9 @@ sub SetValue {
    #$self->{log}->debug ("SetValue GNR: " . $self->GetNumberRows . " pos to add to is " . $row) ;
    confess ("Array out of bounds too much rows")  unless ( $row < $self->GetNumberRows);
    confess ("Array out of bounds too much cols") unless ($col < $self->GetNumberCols);
-   # $$self{array}->[$row][$col]->SetValue($value);
-   #  $self->{array}->[$row] = [] unless defined $self->{array}->[$row];
-   #  $self->{array}->[$row][$col] = $value;
-   #$self->{log}->debug();
 
     my $fname = $self->{fields}->[$col]->{name};
-    $self->{log}->debug("SetValue row : ", $row, " col: ", $col, " field: ", $fname , " value: ", (defined $value ? $value : " undef"));
+    #$self->{log}->debug("SetValue row : ", $row, " col: ", $col, " field: ", $fname , " value: ", (defined $value ? $value : " undef"));
 
      #fait dans apply ... !
      #D'autant plus que $value est la valeur affichee par un combo et non l'id correspondant
