@@ -11,7 +11,7 @@ use Data::Dumper;
 
 use Wx qw[:everything];
 #EVT_DATAVIEW_ITEM_VALUE_CHANGED
-use Wx::Event qw[EVT_TEXT EVT_LIST_ITEM_SELECTED EVT_COMBOBOX EVT_LISTBOX &EVT_CHECKBOX EVT_RADIOBUTTON EVT_SPINCTRL];
+use Wx::Event qw[EVT_TEXT EVT_LIST_ITEM_SELECTED EVT_COMBOBOX EVT_LISTBOX &EVT_CHECKBOX EVT_RADIOBUTTON EVT_SPINCTRL  EVT_TEXT_ENTER];
 
 #'Wx::TextCtrl' => \&_get_textbuffer,
 #'Wx::Calendar' => 'day_selected',
@@ -65,6 +65,7 @@ sub new {
 		dman => $$req{data_manager},
 		cols => $$req{datawidgets},
 		ecols => $$req{datawidgets_changed}, # a documenter: un hash ref {fieldid1 => coderef, fieldid2 => coderef }
+		after_update => $$req{after_update},
 		null_string => $$req{null_string} || "null",
 		builder => $$req{builder},
 		after_insert => $$req{after_insert},
@@ -167,6 +168,11 @@ sub add_childform {
 #
 #renvoyer un hash de la col 0/index dans tous les cas ?
 
+#add the values contained in the array @$aref in the combo $name
+#the combo has to a Wx::ComboBox
+#set the hash ref of row# => id in $self->{datawidgetsValue}->{$field}
+#set the hash ref of id => row# in $self->{datawidgetsPos}->{$field}
+
 sub add_combo_values {
 
 	my ($self, $w, $aref, $name)=@_;
@@ -207,6 +213,11 @@ sub add_combo_values {
        		$self->{datawidgetsPos}->{ $name } = \%idpos;
 
 }
+
+
+#set the hash ref of row# => id in $self->{datawidgetsValue}->{$field}
+#set the hash ref of id => row# in $self->{datawidgetsPos}->{$field}
+#set the combo's datamanager in $self->{comboDman}->{$field}
 sub add_combo{
 	my ($self, $req)=@_;
 
@@ -214,6 +225,7 @@ sub add_combo{
 		dman => $$req{data_manager}, 
 		id => $$req{id},
 		fields=> $$req{fields},
+		init => $$req{init} || 1,
 
 	};
 
@@ -265,6 +277,8 @@ sub add_combo{
 
   my $column =0;
    my $last;
+   
+  #Name is the Wx::XXXX kind of object
   my $name = $self->{datawidgetsName}->{ $combo->{id} };
   #my %idpos;
  my $itemCol;
@@ -307,15 +321,16 @@ my @values;
 
 			    if ($name eq "Wx::ListCtrl") {
 				   $w->InsertStringItem($i, $value);
-			   } elsif ($name eq "Wx::ComboBox" || $name eq "Wx::ListBox") {
+			   } elsif (! ($name eq "Wx::ComboBox" || $name eq "Wx::ListBox")) {
 				   #$idpos{$value}= $i;
-				   $self->{log}->debug("add_combo col 0 index:  $i value: $value");
+				   #$self->{log}->debug("add_combo col 0 index:  $i value: $value");
 				   #my $cd = Wx::ClientData($value);
 				   #$w->SetClientData($i, $value);
 				   #$currid = $value;
 				   #die (Dumper $w->GetClientData($i));
+				     confess ("add_combo: $name is not supported" );
 			      } 
-			   else {$self->{log}->error("add_combo: $name is not supported" ); return;}
+			      #else {$self->{log}->error("add_combo: $name is not supported" ); return;}
 			   
 	            } else {
 		   #my $e = Wx::TextEntry;
@@ -328,7 +343,7 @@ my @values;
 			   } elsif ($name eq "Wx::ComboBox" || $name eq "Wx::ListBox") {
 				   #$w->SetString($i, $value);
 				   $w->Append($value);
-				   $self->{log}->debug("add_combo col $column index:  $i value: $value");
+				   #$self->{log}->debug("add_combo col $column index:  $i value: $value");
 				   #$self->{log}->debug("add_combo: ". $combo->{id} . " row: $i value: $value");
 			   }
 		    }
@@ -344,13 +359,19 @@ my @values;
 	       #$self->{datawidgetsValue}->{ $combo->{id} } = \%idpos;
 	       $self->{datawidgetsValue}->{ $combo->{id} } = \%ids;
        		$self->{datawidgetsPos}->{ $combo->{id} } = \%idpos;
+		my $href =  {fields => $combo->{fields}, dman => $combo->{dman},  };
+		$self->{combo}->{ $combo->{id} } = {dman => $combo->{dman}, fields=> \@cols};
+	
 	} 
 
 	$self->{log}->debug("add_combo: " . $last . " rows added");
 
 	#crase le listener mis dans bind_changed
 	#EVT_LIST_ITEM_SELECTED($self->{builder}->get_object('mainwindow'), $w, sub {$self->_on_selected($combo->{id}, @_)});
-	
+	if ($combo->{init} && $w->GetWindowStyleFlag & wxTE_PROCESS_ENTER ) {
+		$self->{log}->debug("binding text enter for combo " . $combo->{id} );
+		EVT_TEXT_ENTER($self->{builder}->frame, $w, sub {$self->_on_combo_newval($combo->{id}, @_)});	
+	}
 	
 
 #	if ($self->{datawidgetsName}->{$combo->{id}} eq "GtkComboBoxEntry" ){
@@ -493,14 +514,9 @@ sub insert {
 sub delete {
 	my $self = shift;
 	$self->{log}->debug("delete at " . $self->{dman}->get_row_pos );
-	#my $pos = $self->{pos};
-	#my $row =  $self->{data}[$pos];
-	#$row->delete;
 	#$self->next;
 	$self->{changed} = 1;
-	# $self->{dman}->delete;
 	push @{$self->{pos2del}}, $self->{dman}->get_row_pos;
-	#$self->set_rs_range(1);
 	$self->_set_record_status_label;
 
 
@@ -804,9 +820,12 @@ sub _set_textentry {
 	$w->get_buffer->set_text($x || "");
 
 }
-
+# DB -> combo
+# $x : $value received from the DB
+# $id corresponding index
 sub _set_combo {
 	my ($self, $w, $x, $id) = @_;
+	#return unless (defined $x); the combo must be unselect from the preceding value
 	my $name = $self->{datawidgetsName}->{$id};
 	$self->{log}->debug("set_combo value " . ( defined $x ? $x : " undef") . " widget: ". $name );
 	if ($name eq "Wx::ListCtrl") {
@@ -816,24 +835,25 @@ sub _set_combo {
 	
 		$w->SetItemState($item, wxLIST_STATE_SELECTED,  wxLIST_STATE_SELECTED);
         } elsif ($name eq "Wx::ComboBox" || $name eq "Wx::ListBox") {
-		confess ("undef datawidgetsPos  for ", $id) && die unless ($self->{datawidgetsPos}->{$id});
+		confess ("undef datawidgetsPos  for ", $id) unless ($self->{datawidgetsPos}->{$id});
 		my %idpos = %{ $self->{datawidgetsPos}->{$id} };
-		foreach my $k (keys %idpos) {
-			$self->{log}->debug("idpos key: ". $k . " value: " . $idpos{$k});
-		}
+		#foreach my $k (keys %idpos) {
+		#	$self->{log}->debug("idpos key: ". $k . " value: " . $idpos{$k});
+		#}
 		#print "keys: ", join(" ", keys (%idpos)), "\n";
 		#print "values: ", join(" ", values (%idpos)), "\n";
 		# print "value: ", $x, "\n";
 		my $i = $idpos{$x};
 		$self->{log}->debug("_set_combo pos is " . (defined $i ? $i : " undef") );
 		# $w->SetSelection(wxNOT_FOUND);
-		 $w->SetSelection($i) if(defined $i && $i != wxNOT_FOUND);
-		 $self->{log}->debug($w->GetStringSelection);
+		if (defined $i) {
+			 $w->SetSelection($i);
+		 } else {
+			 $w->SetSelection(wxNOT_FOUND);
+		 }
+		 # $self->{log}->debug($w->GetStringSelection);
 	
 	}
-      
-            	
-
 }
 
 
@@ -842,6 +862,24 @@ sub _set_check {
 	$w->set_active( $x );
 }
 
+#$comboid is the combo id and the field name in the table that received the value selected in the combo
+# $field[1] is the name of the field that is displayed in the combo
+# $field[0] is the field name of the values returned from the combo
+sub _on_combo_newval {
+	my ($self, $comboid, $frame, $event) = @_;
+	my $value = $event->GetString;
+	$self->{log}->debug("combo_newval: " . $value);
+	$value = ($value eq "" ? undef : $value);
+	return unless (defined $value);
+	my $href = $self->{combo}->{$comboid};
+	my $dman = $href->{dman};
+	my @fields = @{$href->{fields}};
+	$dman->new_row;
+	$dman->set_field($fields[1], $value);
+	$dman->save;
+	$self->add_combo({data_manager => $dman, fields=>$href->{fields}, id => $comboid, init=>0});
+}
+
 sub _get_combobox_selectedvalue  {
 	my ($self, $id) = @_; 
 
@@ -983,6 +1021,9 @@ sub update{
 	} else {
 		$self->_display_data(-1)
 	}
+	if (defined $self->{after_update}){ 
+		$self->{after_update}();
+	}
 }
 
 #parameter $in_db is 0 or 1 : 
